summaryrefslogtreecommitdiff
path: root/include/llvm/ExecutionEngine
diff options
context:
space:
mode:
authorNicolas Geoffray <nicolas.geoffray@lip6.fr>2008-04-20 17:44:19 +0000
committerNicolas Geoffray <nicolas.geoffray@lip6.fr>2008-04-20 17:44:19 +0000
commit5913e6c5dbaff88ac00d5e679382abc72323831a (patch)
treee9a2f180b907c427651d171380c4c8d82b37f538 /include/llvm/ExecutionEngine
parenta0c8fc6f28808a6b859d45c7e2d3391e3e8d2963 (diff)
downloadllvm-5913e6c5dbaff88ac00d5e679382abc72323831a.tar.gz
llvm-5913e6c5dbaff88ac00d5e679382abc72323831a.tar.bz2
llvm-5913e6c5dbaff88ac00d5e679382abc72323831a.tar.xz
Cosmetic changes, as suggested by Evan. No functionality changes.
git-svn-id: https://llvm.org/svn/llvm-project/llvm/trunk@49993 91177308-0d34-0410-b5e6-96231b3b80d8
Diffstat (limited to 'include/llvm/ExecutionEngine')
-rw-r--r--include/llvm/ExecutionEngine/JITMemoryManager.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/include/llvm/ExecutionEngine/JITMemoryManager.h b/include/llvm/ExecutionEngine/JITMemoryManager.h
index 53900f45ef..e1f2763e1d 100644
--- a/include/llvm/ExecutionEngine/JITMemoryManager.h
+++ b/include/llvm/ExecutionEngine/JITMemoryManager.h
@@ -54,9 +54,9 @@ public:
/// return a pointer to its base.
virtual unsigned char *getGOTBase() const = 0;
/// RequireSize - If the memory manager requires to know the size of the
/// objects to be emitted
- bool RequiresSize() const {
+ bool NeedsExactSize() const {
return SizeRequired;
}
@@ -54,9 +54,9 @@ public:
/// return a pointer to its base.
virtual unsigned char *getGOTBase() const = 0;
- /// RequireSize - If the memory manager requires to know the size of the
+ /// NeedsExactSize - If the memory manager requires to know the size of the
/// objects to be emitted